import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';
//Attaching csv URL
const csvUrl = [
  'https://gist.githubusercontent.com/',
  'curran/', 
  'a08a1080b88344b0c8a7/',
  'raw/0e7a9b0a5d22642a06d3d5b9bcbad9890c8ee534/', 
  'iris.csv', 
].join('');
const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;
  return d;
};
//Width and Height are being assigned
//These values are constant and are set to 
//the windows innerHeight and innerWidth
const width = window.innerWidth;
const height = window.innerHeight;
//appending the svg to body
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

//Creating the async()
//The scatterplot is created with the details
const main = async () => {
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.petal_width)
    .yValue((d) => d.sepal_length)
  	.rxValue((d) => d.sepal_width)
    .ryValue((d) => d.petal_length)
    .speciesValue((d) => d.species)
  	.symbolValue((d) => d.species)
    .margin({
      top: 20,
      right: 20,
      bottom: 40,
      left: 50,
    })
    .radius(5);

  svg.call(plot);
//Columns are initialized below
  const columns = [
    'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length',
  ];
  
//Creating on-page text display
//Showing colors based on species
svg.append('rect')
  .attr('x', 120)
  .attr('y', 50)
  .attr('width', 150)
  .attr('height', 100)
  .attr('stroke', 'black')
  .attr('fill', '#F3F3F3');
svg.append("text").attr("x", 300).attr("y", 20).text("Reusable D3 Scatter Plot").style("font-size", "40px").attr("alignment-baseline","middle").style('fill', '#FF686B').style('font-weight', 'bold')
svg.append("text").attr("x", 150).attr("y", 70).text("Setosa").style("font-size", "25px").style('fill', '#FF686B').style("font-family", "calibri").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 100).text("Versicolor").style("font-size", "25px").style('fill', '#FFA69E').style("font-family", "calibri").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 130).text("Virginica").style("font-size", "25px").style('fill', '#AA4465').style("font-family", "calibri").attr("alignment-baseline","middle")

//Changing the scatterplot after a specific time
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);
    svg.call(plot);
    i++;
    
  }, 1000);
};
main();



